[][src]Struct glob::GlobError

pub struct GlobError { /* fields omitted */ }

A glob iteration error.

This is typically returned when a particular path cannot be read to determine if its contents match the glob pattern. This is possible if the program lacks the appropriate permissions, for example.

Methods

impl GlobError[src]

pub fn path(&self) -> &Path[src]

The Path that the error corresponds to.

pub fn error(&self) -> &Error[src]

The error in question.

pub fn into_error(self) -> Error[src]

Consumes self, returning the raw underlying io::Error