[][src]Struct glob::Pattern

pub struct Pattern { /* fields omitted */ }

A compiled Unix shell style pattern.

Methods

impl Pattern[src]

pub fn new(pattern: &str) -> Result<Self, PatternError>[src]

This function compiles Unix shell style patterns.

An invalid glob pattern will yield a PatternError.

pub fn escape(s: &str) -> String[src]

Escape metacharacters within the given string by surrounding them in brackets. The resulting string will, when compiled into a Pattern, match the input string and nothing else.

pub fn matches(&self, str: &str) -> bool[src]

Return if the given str matches this Pattern using the default match options (i.e. MatchOptions::new()).

Examples

use glob::Pattern;

assert!(Pattern::new("c?t").unwrap().matches("cat"));
assert!(Pattern::new("k[!e]tteh").unwrap().matches("kitteh"));
assert!(Pattern::new("d*g").unwrap().matches("doog"));

pub fn matches_path(&self, path: &Path) -> bool[src]

Return if the given Path, when converted to a str, matches this Pattern using the default match options (i.e. MatchOptions::new()).

pub fn matches_with(&self, str: &str, options: MatchOptions) -> bool[src]

Return if the given str matches this Pattern using the specified match options.

pub fn matches_path_with(&self, path: &Path, options: MatchOptions) -> bool[src]

Return if the given Path, when converted to a str, matches this Pattern using the specified match options.

pub fn as_str(&self) -> &str[src]

Access the original glob pattern.